@@ -16,6 +16,7 @@
 from distutils.version import StrictVersion
 import functools
 from http import client as http_client
+import json
 import logging
 import re
 import textwrap
@@ -24,7 +25,6 @@ from urllib import parse as urlparse
 
 from keystoneauth1 import adapter
 from keystoneauth1 import exceptions as kexc
-from oslo_serialization import jsonutils
 
 from ironicclient.common import filecache
 from ironicclient.common.i18n import _
@@ -37,7 +37,7 @@ from ironicclient import exc
 #             http://specs.openstack.org/openstack/ironic-specs/specs/kilo/api-microversions.html # noqa
 #             for full details.
 DEFAULT_VER = '1.9'
-LAST_KNOWN_API_VERSION = 65
+LAST_KNOWN_API_VERSION = 69
 LATEST_VERSION = '1.{}'.format(LAST_KNOWN_API_VERSION)
 
 LOG = logging.getLogger(__name__)
@@ -67,7 +67,7 @@ def _trim_endpoint_api_version(url):
 def _extract_error_json(body):
     """Return  error_message from the HTTP response body."""
     try:
-        body_json = jsonutils.loads(body)
+        body_json = json.loads(body)
     except ValueError:
         return {}
 
@@ -75,7 +75,7 @@ def _extract_error_json(body):
         return {}
 
     try:
-        error_json = jsonutils.loads(body_json['error_message'])
+        error_json = json.loads(body_json['error_message'])
     except ValueError:
         return body_json
 
@@ -362,6 +362,13 @@ class SessionClient(VersionNegotiationMixin, adapter.LegacyJsonAdapter):
             kwargs['headers'].setdefault('X-OpenStack-Ironic-API-Version',
                                          self.os_ironic_api_version)
 
+        for k, v in self.additional_headers.items():
+            kwargs['headers'].setdefault(k, v)
+
+        if self.global_request_id is not None:
+            kwargs['headers'].setdefault(
+                "X-OpenStack-Request-ID", self.global_request_id)
+
         endpoint_filter = kwargs.setdefault('endpoint_filter', {})
         endpoint_filter.setdefault('interface', self.interface)
         endpoint_filter.setdefault('service_type', self.service_type)
@@ -393,7 +400,7 @@ class SessionClient(VersionNegotiationMixin, adapter.LegacyJsonAdapter):
         kwargs['headers'].setdefault('Accept', 'application/json')
 
         if 'body' in kwargs:
-            kwargs['data'] = jsonutils.dump_as_bytes(kwargs.pop('body'))
+            kwargs['json'] = kwargs.pop('body')
 
         resp = self._http_request(url, method, **kwargs)
         body = resp.content
