@@ -15,8 +15,8 @@
 import copy
 import tempfile
 import time
+from unittest import mock
 
-import mock
 import testtools
 from testtools.matchers import HasLength
 
@@ -36,6 +36,7 @@ NODE1 = {'uuid': '66666666-7777-8888-9999-000000000000',
          'driver_info': {'user': 'foo', 'password': 'bar'},
          'properties': {'num_cpu': 4},
          'name': 'fake-node-1',
+         'network_data': {},
          'resource_class': 'foo',
          'extra': {},
          'conductor_group': 'in-the-closet-to-the-left'}
@@ -46,6 +47,7 @@ NODE2 = {'uuid': '66666666-7777-8888-9999-111111111111',
          'driver': 'fake too',
          'driver_info': {'user': 'foo', 'password': 'bar'},
          'properties': {'num_cpu': 4},
+         'network_data': {},
          'resource_class': 'bar',
          'extra': {},
          'owner': '33333333-2222-1111-0000-111111111111',
@@ -1498,6 +1500,15 @@ class NodeManagerTest(testtools.TestCase):
         ]
         self.assertEqual(expect, self.api.calls)
 
+    def test_node_set_provision_state_with_configdrive_invalid_bytes(self):
+        invalid_utf8 = b"\xc3\x28"
+        target_state = 'active'
+        self.assertRaisesRegex(ValueError,
+                               'Config drive',
+                               self.mgr.set_provision_state,
+                               NODE1['uuid'], target_state,
+                               configdrive=invalid_utf8)
+
     def test_node_set_provision_state_with_configdrive_as_dict(self):
         target_state = 'active'
         self.mgr.set_provision_state(NODE1['uuid'], target_state,
@@ -1518,7 +1529,8 @@ class NodeManagerTest(testtools.TestCase):
             self.mgr.set_provision_state(NODE1['uuid'], target_state,
                                          configdrive=f.name)
 
-        body = {'target': target_state, 'configdrive': file_content}
+        body = {'target': target_state,
+                'configdrive': file_content.decode('utf-8')}
         expect = [
             ('PUT', '/v1/nodes/%s/states/provision' % NODE1['uuid'], {}, body),
         ]
@@ -1552,6 +1564,31 @@ class NodeManagerTest(testtools.TestCase):
         ]
         self.assertEqual(expect, self.api.calls)
 
+    def test_node_set_provision_state_with_deploysteps(self):
+        deploysteps = [{"step": "upgrade", "interface": "deploy"}]
+        target_state = 'active'
+        self.mgr.set_provision_state(NODE1['uuid'], target_state,
+                                     deploysteps=deploysteps)
+        body = {'target': target_state, 'deploy_steps': deploysteps}
+        expect = [
+            ('PUT', '/v1/nodes/%s/states/provision' % NODE1['uuid'], {}, body),
+        ]
+        self.assertEqual(expect, self.api.calls)
+
+    def test_node_set_provision_state_with_configdrive_and_deploysteps(self):
+        deploysteps = [{"step": "upgrade", "interface": "deploy"}]
+        target_state = 'active'
+        self.mgr.set_provision_state(NODE1['uuid'], target_state,
+                                     configdrive={'user_data': ''},
+                                     deploysteps=deploysteps)
+        body = {'target': target_state,
+                'configdrive': {'user_data': ''},
+                'deploy_steps': deploysteps}
+        expect = [
+            ('PUT', '/v1/nodes/%s/states/provision' % NODE1['uuid'], {}, body),
+        ]
+        self.assertEqual(expect, self.api.calls)
+
     def test_node_set_provision_state_with_rescue_password(self):
         rescue_password = 'supersecret'
         target_state = 'rescue'
@@ -1618,9 +1655,10 @@ class NodeManagerTest(testtools.TestCase):
         for http_method in ('POST', 'PUT', 'PATCH'):
             kwargs['http_method'] = http_method
             self.mgr.vendor_passthru(**kwargs)
-            update_mock.assert_called_once_with(mock.ANY, final_path,
-                                                vendor_passthru_args,
-                                                http_method=http_method)
+            update_mock.assert_called_once_with(
+                mock.ANY, final_path, vendor_passthru_args,
+                http_method=http_method, os_ironic_api_version=None,
+                global_request_id=None)
             update_mock.reset_mock()
 
     @mock.patch.object(node.NodeManager, 'get', autospec=True)
@@ -1633,7 +1671,9 @@ class NodeManagerTest(testtools.TestCase):
 
         final_path = 'node_uuid/vendor_passthru/method'
         self.mgr.vendor_passthru(**kwargs)
-        get_mock.assert_called_once_with(mock.ANY, final_path)
+        get_mock.assert_called_once_with(
+            mock.ANY, final_path,
+            os_ironic_api_version=None, global_request_id=None)
 
     @mock.patch.object(node.NodeManager, 'delete', autospec=True)
     def test_vendor_passthru_delete(self, delete_mock):
@@ -1645,7 +1685,9 @@ class NodeManagerTest(testtools.TestCase):
 
         final_path = 'node_uuid/vendor_passthru/method'
         self.mgr.vendor_passthru(**kwargs)
-        delete_mock.assert_called_once_with(mock.ANY, final_path)
+        delete_mock.assert_called_once_with(
+            mock.ANY, final_path, os_ironic_api_version=None,
+            global_request_id=None)
 
     @mock.patch.object(node.NodeManager, 'delete', autospec=True)
     def test_vendor_passthru_unknown_http_method(self, delete_mock):
@@ -1665,7 +1707,9 @@ class NodeManagerTest(testtools.TestCase):
 
         final_path = '/v1/nodes/%s/vifs' % NODE1['uuid']
         self.mgr.vif_list(**kwargs)
-        _list_mock.assert_called_once_with(mock.ANY, final_path, "vifs")
+        _list_mock.assert_called_once_with(
+            mock.ANY, final_path, "vifs",
+            os_ironic_api_version=None, global_request_id=None)
 
     @mock.patch.object(node.NodeManager, 'update', autospec=True)
     def test_vif_attach(self, update_mock):
@@ -1677,7 +1721,8 @@ class NodeManagerTest(testtools.TestCase):
         final_path = '%s/vifs' % NODE1['uuid']
         self.mgr.vif_attach(**kwargs)
         update_mock.assert_called_once_with(
-            mock.ANY, final_path, {'id': 'vif_id'}, http_method="POST")
+            mock.ANY, final_path, {'id': 'vif_id'}, http_method="POST",
+            os_ironic_api_version=None, global_request_id=None)
 
     @mock.patch.object(node.NodeManager, 'update', autospec=True)
     def test_vif_attach_custom_fields(self, update_mock):
@@ -1692,7 +1737,8 @@ class NodeManagerTest(testtools.TestCase):
         update_mock.assert_called_once_with(
             mock.ANY,
             final_path, {'id': 'vif_id', 'foo': 'bar'},
-            http_method="POST")
+            http_method="POST", os_ironic_api_version=None,
+            global_request_id=None)
 
     @mock.patch.object(node.NodeManager, 'update', autospec=True)
     def test_vif_attach_custom_fields_id(self, update_mock):
@@ -1714,7 +1760,9 @@ class NodeManagerTest(testtools.TestCase):
 
         final_path = '%s/vifs/vif_id' % NODE1['uuid']
         self.mgr.vif_detach(**kwargs)
-        delete_mock.assert_called_once_with(mock.ANY, final_path)
+        delete_mock.assert_called_once_with(
+            mock.ANY, final_path,
+            os_ironic_api_version=None, global_request_id=None)
 
     def _test_node_set_boot_device(self, boot_device, persistent=False):
         self.mgr.set_boot_device(NODE1['uuid'], boot_device, persistent)
@@ -1786,7 +1834,9 @@ class NodeManagerTest(testtools.TestCase):
 
         self.mgr.wait_for_provision_state('node', 'active')
 
-        mock_get.assert_called_with(self.mgr, 'node')
+        mock_get.assert_called_with(
+            self.mgr, 'node', os_ironic_api_version=None,
+            global_request_id=None)
         self.assertEqual(3, mock_get.call_count)
         mock_sleep.assert_called_with(node._DEFAULT_POLL_INTERVAL)
         self.assertEqual(2, mock_sleep.call_count)
@@ -1814,7 +1864,9 @@ class NodeManagerTest(testtools.TestCase):
                                self.mgr.wait_for_provision_state,
                                'node', 'active')
 
-        mock_get.assert_called_with(self.mgr, 'node')
+        mock_get.assert_called_with(
+            self.mgr, 'node',
+            os_ironic_api_version=None, global_request_id=None)
         self.assertEqual(2, mock_get.call_count)
         mock_sleep.assert_called_with(node._DEFAULT_POLL_INTERVAL)
         self.assertEqual(1, mock_sleep.call_count)
@@ -1830,7 +1882,9 @@ class NodeManagerTest(testtools.TestCase):
         self.mgr.wait_for_provision_state('node', 'active',
                                           poll_delay_function=delay_mock)
 
-        mock_get.assert_called_with(self.mgr, 'node')
+        mock_get.assert_called_with(
+            self.mgr, 'node',
+            os_ironic_api_version=None, global_request_id=None)
         self.assertEqual(2, mock_get.call_count)
         delay_mock.assert_called_with(node._DEFAULT_POLL_INTERVAL)
         self.assertEqual(1, delay_mock.call_count)
@@ -1858,7 +1912,9 @@ class NodeManagerTest(testtools.TestCase):
                                self.mgr.wait_for_provision_state,
                                'node', 'active')
 
-        mock_get.assert_called_with(self.mgr, 'node')
+        mock_get.assert_called_with(
+            self.mgr, 'node', os_ironic_api_version=None,
+            global_request_id=None)
         self.assertEqual(2, mock_get.call_count)
         mock_sleep.assert_called_with(node._DEFAULT_POLL_INTERVAL)
         self.assertEqual(1, mock_sleep.call_count)
@@ -1877,7 +1933,9 @@ class NodeManagerTest(testtools.TestCase):
         self.mgr.wait_for_provision_state('node', 'active',
                                           fail_on_unexpected_state=False)
 
-        mock_get.assert_called_with(self.mgr, 'node')
+        mock_get.assert_called_with(
+            self.mgr, 'node',
+            os_ironic_api_version=None, global_request_id=None)
         self.assertEqual(4, mock_get.call_count)
         mock_sleep.assert_called_with(node._DEFAULT_POLL_INTERVAL)
         self.assertEqual(3, mock_sleep.call_count)
